volumeHandler

package
v0.0.0-...-7739612 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 12, 2025 License: GPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetAudioDeviceName

func GetAudioDeviceName() (string, error)

GetAudioDeviceName returns a readable name for the active audio device.

func GetAudioIcon

func GetAudioIcon() (string, error)

GetAudioIcon dynamically selects the icon based on the device type and volume level.

Types

This section is empty.

Jump to