Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetAudioDeviceName ¶
GetAudioDeviceName returns a readable name for the active audio device.
func GetAudioIcon ¶
GetAudioIcon dynamically selects the icon based on the device type and volume level.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.